pub struct SetOperator {
pub vault: Pubkey,
pub operator: Pubkey,
pub admin: Pubkey,
}Expand description
Generated client accounts for SetOperator.
Fields
vault: Pubkeyoperator: Pubkeyadmin: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetOperatorwhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetOperatorwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetOperator
impl ToAccountMetas for SetOperator
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetOperator
impl RefUnwindSafe for SetOperator
impl Send for SetOperator
impl Sync for SetOperator
impl Unpin for SetOperator
impl UnwindSafe for SetOperator