pub struct InitializeStrategy {
pub _bumps: StrategyBumps,
pub _strategy_type: StrategyType,
}Expand description
Instruction.
Fields
_bumps: StrategyBumps_strategy_type: StrategyTypeTrait Implementations
Sourceimpl BorshDeserialize for InitializeStrategy
impl BorshDeserialize for InitializeStrategy
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitializeStrategy
impl BorshSerialize for InitializeStrategy
Sourceimpl Discriminator for InitializeStrategy
impl Discriminator for InitializeStrategy
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for InitializeStrategy
impl InstructionData for InitializeStrategy