pub struct Strategy {
pub reserve: Pubkey,
pub collateral_vault: Pubkey,
pub strategy_type: StrategyType,
pub current_liquidity: u64,
pub bumps: [u8; 10],
pub vault: Pubkey,
pub is_disable: u8,
}Expand description
Account: Strategy
Fields
reserve: Pubkeycollateral_vault: Pubkeystrategy_type: StrategyTypecurrent_liquidity: u64bumps: [u8; 10]vault: Pubkeyis_disable: u8Trait Implementations
Sourceimpl AccountDeserialize for Strategy
impl AccountDeserialize for Strategy
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Strategy
impl AccountSerialize for Strategy
Sourceimpl BorshDeserialize for Strategywhere
Pubkey: BorshDeserialize,
StrategyType: BorshDeserialize,
u64: BorshDeserialize,
[u8; 10]: BorshDeserialize,
u8: BorshDeserialize,
impl BorshDeserialize for Strategywhere
Pubkey: BorshDeserialize,
StrategyType: BorshDeserialize,
u64: BorshDeserialize,
[u8; 10]: BorshDeserialize,
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Strategywhere
Pubkey: BorshSerialize,
StrategyType: BorshSerialize,
u64: BorshSerialize,
[u8; 10]: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for Strategywhere
Pubkey: BorshSerialize,
StrategyType: BorshSerialize,
u64: BorshSerialize,
[u8; 10]: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Discriminator for Strategy
impl Discriminator for Strategy
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for Strategy